==> kubernetes-model-core-6.9.0-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeStatusFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PersistentVolumeStatusFluent<A extends PersistentVolumeStatusFluent<A>> extends BaseFluent<A>{
  public PersistentVolumeStatusFluent() {
  }
  
  public PersistentVolumeStatusFluent(PersistentVolumeStatus instance) {
    this.copyInstance(instance);
  }
  private String lastPhaseTransitionTime;
  private String message;
  private String phase;
  private String reason;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(PersistentVolumeStatus instance) {
    instance = (instance != null ? instance : new PersistentVolumeStatus());
  
    if (instance != null) {
        this.withLastPhaseTransitionTime(instance.getLastPhaseTransitionTime());
        this.withMessage(instance.getMessage());
        this.withPhase(instance.getPhase());
        this.withReason(instance.getReason());
        this.withLastPhaseTransitionTime(instance.getLastPhaseTransitionTime());
        this.withMessage(instance.getMessage());
        this.withPhase(instance.getPhase());
        this.withReason(instance.getReason());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public String getLastPhaseTransitionTime() {
    return this.lastPhaseTransitionTime;
  }
  
  public A withLastPhaseTransitionTime(String lastPhaseTransitionTime) {
    this.lastPhaseTransitionTime=lastPhaseTransitionTime; return (A) this;
  }
  
  public boolean hasLastPhaseTransitionTime() {
    return this.lastPhaseTransitionTime != null;
  }
  
  public String getMessage() {
    return this.message;
  }
  
  public A withMessage(String message) {
    this.message=message; return (A) this;
  }
  
  public boolean hasMessage() {
    return this.message != null;
  }
  
  public String getPhase() {
    return this.phase;
  }
  
  public A withPhase(String phase) {
    this.phase=phase; return (A) this;
  }
  
  public boolean hasPhase() {
    return this.phase != null;
  }
  
  public String getReason() {
    return this.reason;
  }
  
  public A withReason(String reason) {
    this.reason=reason; return (A) this;
  }
  
  public boolean hasReason() {
    return this.reason != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PersistentVolumeStatusFluent that = (PersistentVolumeStatusFluent) o;
    if (!java.util.Objects.equals(lastPhaseTransitionTime, that.lastPhaseTransitionTime)) return false;
  
    if (!java.util.Objects.equals(message, that.message)) return false;
  
    if (!java.util.Objects.equals(phase, that.phase)) return false;
  
    if (!java.util.Objects.equals(reason, that.reason)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(lastPhaseTransitionTime,  message,  phase,  reason,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lastPhaseTransitionTime != null) { sb.append("lastPhaseTransitionTime:"); sb.append(lastPhaseTransitionTime + ","); }
    if (message != null) { sb.append("message:"); sb.append(message + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}

==> kubernetes-model-core-6.9.1-sources.jar: io/fabric8/kubernetes/api/model/PersistentVolumeStatusFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.LinkedHashMap;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class PersistentVolumeStatusFluent<A extends PersistentVolumeStatusFluent<A>> extends BaseFluent<A>{
  public PersistentVolumeStatusFluent() {
  }
  
  public PersistentVolumeStatusFluent(PersistentVolumeStatus instance) {
    this.copyInstance(instance);
  }
  private String lastPhaseTransitionTime;
  private String message;
  private String phase;
  private String reason;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(PersistentVolumeStatus instance) {
    instance = (instance != null ? instance : new PersistentVolumeStatus());
    if (instance != null) {
          this.withLastPhaseTransitionTime(instance.getLastPhaseTransitionTime());
          this.withMessage(instance.getMessage());
          this.withPhase(instance.getPhase());
          this.withReason(instance.getReason());
          this.withLastPhaseTransitionTime(instance.getLastPhaseTransitionTime());
          this.withMessage(instance.getMessage());
          this.withPhase(instance.getPhase());
          this.withReason(instance.getReason());
          this.withAdditionalProperties(instance.getAdditionalProperties());
        }
  }
  
  public String getLastPhaseTransitionTime() {
    return this.lastPhaseTransitionTime;
  }
  
  public A withLastPhaseTransitionTime(String lastPhaseTransitionTime) {
    this.lastPhaseTransitionTime = lastPhaseTransitionTime;
    return (A) this;
  }
  
  public boolean hasLastPhaseTransitionTime() {
    return this.lastPhaseTransitionTime != null;
  }
  
  public String getMessage() {
    return this.message;
  }
  
  public A withMessage(String message) {
    this.message = message;
    return (A) this;
  }
  
  public boolean hasMessage() {
    return this.message != null;
  }
  
  public String getPhase() {
    return this.phase;
  }
  
  public A withPhase(String phase) {
    this.phase = phase;
    return (A) this;
  }
  
  public boolean hasPhase() {
    return this.phase != null;
  }
  
  public String getReason() {
    return this.reason;
  }
  
  public A withReason(String reason) {
    this.reason = reason;
    return (A) this;
  }
  
  public boolean hasReason() {
    return this.reason != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) {
      this.additionalProperties = null;
    } else {
      this.additionalProperties = new LinkedHashMap(additionalProperties);
    }
    return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PersistentVolumeStatusFluent that = (PersistentVolumeStatusFluent) o;
    if (!java.util.Objects.equals(lastPhaseTransitionTime, that.lastPhaseTransitionTime)) return false;
    if (!java.util.Objects.equals(message, that.message)) return false;
    if (!java.util.Objects.equals(phase, that.phase)) return false;
    if (!java.util.Objects.equals(reason, that.reason)) return false;
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(lastPhaseTransitionTime,  message,  phase,  reason,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (lastPhaseTransitionTime != null) { sb.append("lastPhaseTransitionTime:"); sb.append(lastPhaseTransitionTime + ","); }
    if (message != null) { sb.append("message:"); sb.append(message + ","); }
    if (phase != null) { sb.append("phase:"); sb.append(phase + ","); }
    if (reason != null) { sb.append("reason:"); sb.append(reason + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  

}
